@@ -1,5 +1,7 @@
 import json
 import logging
+from collections.abc import Sequence
+from typing import Union
 
 from aiohttp import ClientError, web
 from aiohttp_security import check_authorized
@@ -7,12 +9,11 @@ from aiohttp_security.api import AUTZ_KEY
 
 from .client import Permission
 
-
 logger = logging.getLogger(__name__)
 
 
 async def check_permissions(
-    request: web.Request, permissions: list[Permission]
+    request: web.Request, permissions: Sequence[Union[Permission, Sequence[Permission]]]
 ) -> None:
     user_name = await check_authorized(request)
     auth_policy = request.config_dict.get(AUTZ_KEY)
